NAME="zsh"
DESC="Z shell"
VERSION="5.9"

FILES=(
  "https://www.zsh.org/pub/zsh-${VERSION}.tar.xz"
  "https://www.zsh.org/pub/zsh-${VERSION}-doc.tar.xz"
  "zsh-${VERSION}-avoid-incompatible-pointer-types.patch"
  "zsh-${VERSION}-support-texinfo-7-0.patch"
)
HASHES=(
  "182e37ca3fe3fa6a44f69ad462c5c30e"
  "8db53446f613521fb4f9b0bd9f6adda1"
  "984c804bfa4c7c9b1ddba9f18bbd29846bf6f2b3171f39bb775c11c8b1c7b5ad2c68d2922a59265c58f6e83016d6d440d64862c529d82f90cad308fd2af757ce"
  "891577e8c3a5beb236a7044a0960a014d8a7149ce5dba7715f07b1e4d2db475f4aab7bb6cfeadaaeffe37fb889836f368467882fba1a5ac23076548185432d51"
)

DEPENDS=("gdbm" "libcap" "pcre2" "grep") # grep needed for INSTALL
BUILD=()

PACKAGE() {
  tar xf "${NAME}-${VERSION}.tar.xz"
  cd "${NAME}-${VERSION}"

  patch -Np1 < "../zsh-${VERSION}-avoid-incompatible-pointer-types.patch"
  patch -Np1 < "../zsh-${VERSION}-support-texinfo-7-0.patch"

  tar --strip-components=1 -xvf "../zsh-${VERSION}-doc.tar.xz"
  ./configure --prefix=/usr          \
            --sysconfdir=/etc/zsh    \
            --enable-etcdir=/etc/zsh \
            --enable-cap             \
            --enable-gdbm                             
  
  make
  makeinfo Doc/zsh.texi --plaintext -o Doc/zsh.txt 
  makeinfo Doc/zsh.texi --html      -o Doc/html
  makeinfo Doc/zsh.texi --html --no-split --no-headers -o Doc/zsh.html

  make DESTDIR="${ROOTDIR}" install
  make DESTDIR="${ROOTDIR}" infodir=/usr/share/info install.info

  install -v -m755 -d                 "${ROOTDIR}/usr/share/doc/zsh-${VERSION}/html"
  install -v -m644 Doc/html/*         "${ROOTDIR}/usr/share/doc/zsh-${VERSION}/html"
  install -v -m644 Doc/zsh.{html,txt} "${ROOTDIR}/usr/share/doc/zsh-${VERSION}"

  cd .. && rm -rf "${NAME}-${VERSION}"
}

INSTALL(){
  # add zsh to /etc/shells if not already exists
  if ! grep -q "/bin/zsh" "/etc/shells"; then
    echo /bin/zsh >> /etc/shells
  fi
}
